# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_entity_in_db import KnowledgeEntityInDb

class TestKnowledgeEntityInDb(unittest.TestCase):
    """KnowledgeEntityInDb unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeEntityInDb:
        """Test KnowledgeEntityInDb
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeEntityInDb`
        """
        model = KnowledgeEntityInDb()
        if include_optional:
            return KnowledgeEntityInDb(
                batch_id = '',
                client_id = 'cli_...',
                data = neurograph.v1.models.data.data(),
                ext = neurograph.v1.models.knowledge/entity_extra.knowledge.EntityExtra(
                    customer_id = 56, 
                    domain = '', 
                    product_id = 56, ),
                extra = neurograph.v1.models.extra.extra(),
                id = 'ent_123',
                kind = 'Product|Customer|Store',
                name = 'GiBoard Gel',
                relations = neurograph.v1.models.knowledge/entity_relations.knowledge.EntityRelations(
                    children = [[ent_789]], 
                    parents = [[ent_123,  ent_456]], 
                    siblings = [[ent_999]], ),
                var_schema = neurograph.v1.models.knowledge/entity_schema.knowledge.EntitySchema(
                    id = '@axon/commerce/product:1.0.0', 
                    params = neurograph.v1.models.params.params(), ),
                source_id = '',
                source_updated_at = 56,
                ts_created = 56,
                ts_updated = 56
            )
        else:
            return KnowledgeEntityInDb(
        )
        """

    def testKnowledgeEntityInDb(self):
        """Test KnowledgeEntityInDb"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_gamma_theme_request import OrganizationsGammaThemeRequest

class TestOrganizationsGammaThemeRequest(unittest.TestCase):
    """OrganizationsGammaThemeRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsGammaThemeRequest:
        """Test OrganizationsGammaThemeRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsGammaThemeRequest`
        """
        model = OrganizationsGammaThemeRequest()
        if include_optional:
            return OrganizationsGammaThemeRequest(
                accent_color = '#0CB04A',
                background_color = '#F7F8FA',
                border_color = '#D3D9E0',
                brand_personality = 'professional, innovative, trustworthy',
                brand_reasoning = 'Professional color palette with high contrast',
                brand_style = 'Modern, Professional',
                industry = 'E-commerce',
                primary_color = '#0E5B33',
                secondary_color = '#F28B30',
                source_url = 'https://example.com',
                surface_color = '#FFFFFF',
                target_audience = 'Enterprise customers',
                text_color = '#111111',
                text_secondary_color = '#5E6B78'
            )
        else:
            return OrganizationsGammaThemeRequest(
        )
        """

    def testOrganizationsGammaThemeRequest(self):
        """Test OrganizationsGammaThemeRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
